@@ -1,6 +1,6 @@
 /**
  * @file  wcngdmn.c
- * @copyright Copyright (C) 2019-2020 Michał Bąbik
+ * @copyright Copyright (C) 2019-2021 Michał Bąbik
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,9 +19,9 @@
  *
  * Automatic wallpaper changer
  *
- * @date December 19, 2020
+ * @date January 22, 2021
  *
- * @version 1.6.15
+ * @version 1.6.16
  *
  * @author Michal Babik <michal.babik@pm.me>
  */
@@ -96,19 +96,14 @@ main (int    argc,
     }
     while (1) {
         ui_sleep = ui_ch_int;
-        /* Time align enabled */
-        if (i_atime_opt) {
-            /* If counter is 0 count align sleep time and
-             * number of standard interval sleeps before getting
-             * to full hour */
-            if (ui_cnt > 0) {
-                --ui_cnt;
-            }
-            else {
-                ui_sleep = check_time_align_val (ui_ch_int, &ui_cnt);
-            }
+        /* Time align enabled
+         * If counter is 0 count align sleep time and
+         * number of standard interval sleeps before getting
+         * to full hour */
+        if (i_atime_opt && ui_cnt-- == 0) {
+            ui_sleep = check_time_align_val (ui_ch_int, &ui_cnt);
         }
-        if (ui_sleep != 0) {
+        if (ui_sleep) {
             sleep (ui_sleep);
             ui_ch_int_n = chk_setts_ch_wall (s_cfgfile, rm_rand, &i_atime_opt);
         }
